==> kubernetes-model-kustomize-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SecretArgsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SecretArgsFluent<A extends SecretArgsFluent<A>> extends Fluent<A>{
  public String getBehavior();
  public A withBehavior(String behavior);
  public Boolean hasBehavior();
  public String getEnv();
  public A withEnv(String env);
  public Boolean hasEnv();
  public A addToEnvs(Integer index,String item);
  public A setToEnvs(Integer index,String item);
  public A addToEnvs(java.lang.String... items);
  public A addAllToEnvs(Collection<String> items);
  public A removeFromEnvs(java.lang.String... items);
  public A removeAllFromEnvs(Collection<String> items);
  public List<String> getEnvs();
  public String getEnv(Integer index);
  public String getFirstEnv();
  public String getLastEnv();
  public String getMatchingEnv(Predicate<String> predicate);
  public Boolean hasMatchingEnv(Predicate<String> predicate);
  public A withEnvs(List<String> envs);
  public A withEnvs(java.lang.String... envs);
  public Boolean hasEnvs();
  public A addToFiles(Integer index,String item);
  public A setToFiles(Integer index,String item);
  public A addToFiles(java.lang.String... items);
  public A addAllToFiles(Collection<String> items);
  public A removeFromFiles(java.lang.String... items);
  public A removeAllFromFiles(Collection<String> items);
  public List<String> getFiles();
  public String getFile(Integer index);
  public String getFirstFile();
  public String getLastFile();
  public String getMatchingFile(Predicate<String> predicate);
  public Boolean hasMatchingFile(Predicate<String> predicate);
  public A withFiles(List<String> files);
  public A withFiles(java.lang.String... files);
  public Boolean hasFiles();
  public A addToLiterals(Integer index,String item);
  public A setToLiterals(Integer index,String item);
  public A addToLiterals(java.lang.String... items);
  public A addAllToLiterals(Collection<String> items);
  public A removeFromLiterals(java.lang.String... items);
  public A removeAllFromLiterals(Collection<String> items);
  public List<String> getLiterals();
  public String getLiteral(Integer index);
  public String getFirstLiteral();
  public String getLastLiteral();
  public String getMatchingLiteral(Predicate<String> predicate);
  public Boolean hasMatchingLiteral(Predicate<String> predicate);
  public A withLiterals(List<String> literals);
  public A withLiterals(java.lang.String... literals);
  public Boolean hasLiterals();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  
  /**
   * This method has been deprecated, please use method buildOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public GeneratorOptions getOptions();
  public GeneratorOptions buildOptions();
  public A withOptions(GeneratorOptions options);
  public Boolean hasOptions();
  public SecretArgsFluent.OptionsNested<A> withNewOptions();
  public SecretArgsFluent.OptionsNested<A> withNewOptionsLike(GeneratorOptions item);
  public SecretArgsFluent.OptionsNested<A> editOptions();
  public SecretArgsFluent.OptionsNested<A> editOrNewOptions();
  public SecretArgsFluent.OptionsNested<A> editOrNewOptionsLike(GeneratorOptions item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OptionsNested<N> extends Nested<N>,GeneratorOptionsFluent<SecretArgsFluent.OptionsNested<N>>{
    public N and();
    public N endOptions();
    
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SecretArgsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SecretArgsFluent<A extends SecretArgsFluent<A>> extends Fluent<A>{
  public String getBehavior();
  public A withBehavior(String behavior);
  public Boolean hasBehavior();
  public String getEnv();
  public A withEnv(String env);
  public Boolean hasEnv();
  public A addToEnvs(int index,String item);
  public A setToEnvs(int index,String item);
  public A addToEnvs(java.lang.String... items);
  public A addAllToEnvs(Collection<String> items);
  public A removeFromEnvs(java.lang.String... items);
  public A removeAllFromEnvs(Collection<String> items);
  public List<String> getEnvs();
  public String getEnv(int index);
  public String getFirstEnv();
  public String getLastEnv();
  public String getMatchingEnv(Predicate<String> predicate);
  public Boolean hasMatchingEnv(Predicate<String> predicate);
  public A withEnvs(List<String> envs);
  public A withEnvs(java.lang.String... envs);
  public Boolean hasEnvs();
  public A addToFiles(int index,String item);
  public A setToFiles(int index,String item);
  public A addToFiles(java.lang.String... items);
  public A addAllToFiles(Collection<String> items);
  public A removeFromFiles(java.lang.String... items);
  public A removeAllFromFiles(Collection<String> items);
  public List<String> getFiles();
  public String getFile(int index);
  public String getFirstFile();
  public String getLastFile();
  public String getMatchingFile(Predicate<String> predicate);
  public Boolean hasMatchingFile(Predicate<String> predicate);
  public A withFiles(List<String> files);
  public A withFiles(java.lang.String... files);
  public Boolean hasFiles();
  public A addToLiterals(int index,String item);
  public A setToLiterals(int index,String item);
  public A addToLiterals(java.lang.String... items);
  public A addAllToLiterals(Collection<String> items);
  public A removeFromLiterals(java.lang.String... items);
  public A removeAllFromLiterals(Collection<String> items);
  public List<String> getLiterals();
  public String getLiteral(int index);
  public String getFirstLiteral();
  public String getLastLiteral();
  public String getMatchingLiteral(Predicate<String> predicate);
  public Boolean hasMatchingLiteral(Predicate<String> predicate);
  public A withLiterals(List<String> literals);
  public A withLiterals(java.lang.String... literals);
  public Boolean hasLiterals();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  
  /**
   * This method has been deprecated, please use method buildOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public GeneratorOptions getOptions();
  public GeneratorOptions buildOptions();
  public A withOptions(GeneratorOptions options);
  public Boolean hasOptions();
  public SecretArgsFluent.OptionsNested<A> withNewOptions();
  public SecretArgsFluent.OptionsNested<A> withNewOptionsLike(GeneratorOptions item);
  public SecretArgsFluent.OptionsNested<A> editOptions();
  public SecretArgsFluent.OptionsNested<A> editOrNewOptions();
  public SecretArgsFluent.OptionsNested<A> editOrNewOptionsLike(GeneratorOptions item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OptionsNested<N> extends Nested<N>,GeneratorOptionsFluent<SecretArgsFluent.OptionsNested<N>>{
    public N and();
    public N endOptions();
    
  }
  
}
